require 'test/unit'

require 'rledger/ledger/amount.rb'

class AmountTest < Test::Unit::TestCase
  # def setup
  # end

  # def teardown
  # end

  def test_parse
    a1 = Amount.new
    a1.parse("")
    result = (a1.amount == 0.00 and a1.currency == "")
    assert result, "Derived entry not parsed"

    a2 = Amount.new
    a2.parse("100.00")
    result = (a2.amount = 100.00 and a2.currency = "")
    assert result, "Simple amount not parsed"

    a3 = Amount.new
    a3.parse("EUR 200.00")
    result = (a3.amount = 200.00 and a1.currency = "EUR")
    assert result, "Amount with currency not parsed."
  end

  def test_derived
    assert Amount.derived?(""), "Derived does not work."
    assert not Amount.derived?("100.00"), "Derived does not work"
  end

  def test_add!
    a1 = Amount.new
    a1.parse("EUR 100.00")

    a2 = Amount.new
    a2.parse("MTN 200.00")

    a1.add!(a2)
    assert a1.to_s == "EUR 100.00, MTN 200.00", "Adding different currencies does not work"

    a3 = Amount.new
    a3.parse("EUR 200.00")

    a1.add!(a3)
    assert a1.to_s == "EUR 300.00, MTN 200.00", "Adding different currencies does not work"
  end

  def test_multiply!
    a1 = Amount.new
    a1.parse("EUR 100.00")
    a1.multiply(-2)

    assert (a1.amount == -200.00 and a1.currency == "EUR"), "Multiply single amount does not work"
  end

end

