require 'test/unit'

require 'Date'
require 'rledger/ledger/transaction'

class TransactionTest < Test::Unit::TestCase
  def test_tbase_parse
    tb = TransactionBase.new
    tb.parse "15/02/2010 ! (ID) Payee long"
    result = tb.date == Date.civil(2010, 02, 15) and
      tb.id == "ID" and
      tb.reconciliation.pending! and
      tb.payee = "Payee long"
    assert result

    tb = TransactionBase.new
    tb.parse "15/02/2008 (ID) Payee long"
    result = tb.date == Date.civil(2008, 02, 15) and
      tb.id == "ID" and
      tb.reconciliation.unknown? and
      tb.payee = "Payee long"
    assert result

    tb = TransactionBase.new
    tb.parse "15/06/2010 * Payee very long"
    result = tb.date == Date.civil(2010, 06, 15) and
      tb.id == "" and
      tb.reconciliation.reconciled? and
      tb.payee = "Payee very long"
    assert result

    tb = TransactionBase.new
    tb.parse "15/02/2010 Payee very long"
    result = tb.date == Date.civil(2010, 02, 15) and
      tb.id == "" and
      tb.reconciliation.unknown? and
      tb.payee = "Payee very long"
    assert result

    tb = TransactionBase.new
    tb.parse "15/02/2010"
    result = tb.date == Date.civil(2010, 02, 15) and
      tb.id == "" and
      tb.reconciliation.unknown? and
      tb.payee = ""
    assert result
  end

  def test_t_parse
    t = Transaction.new
    t.parse("15/02/2010 ! (ID) Payee long\n voice 10.00 ; comment\n  other_voice 20.00 ; other comment")
    result = t.date == Date.civil(2010, 02, 15) and
      t.id == "ID" and
      t.reconciliation.pending! and
      t.payee = "Payee long" and
      t.entries.size == 2
    assert result

    post = t.posts[0]
    result = post.item == "voice" and post.amount == "10.00" and post.comment == "comment"
    assert result

    post = t.posts[1]
    result = post.item == "other_voice" and post.amount == "20.00" and post.comment == "other comment"
    assert result
  end

end
